module Gargantext.Hooks.UseFeatureFlag where

import Prelude
import Effect (Effect)
import Effect.Uncurried (runEffectFn1, EffectFn1)
import Gargantext.Utils.Reactix as R2
import Reactix as R
import Reactix.DOM.HTML as H
foreign import _useFeatureFlag :: EffectFn1 (Array String) Boolean
{-
  useFeatureFlag is a custom React hook that determines whether a feature flag is enabled based on the presence and value of specific cookies. 
  It checks the cookies provided as keys and returns true if any of them are set to 'true'. Otherwise, it returns false.
  This hook is useful for conditional rendering of features based on user-specific settings or feature toggles managed via cookies.
  Usage :
parentCpt :: R.Component ()
parentCpt = here.component "container" cpt
  where
  cpt _ _ = do
    shouldBeVisible <- useFeatureFlag ["keyOne", "keyTwo", "keyThree"]
    pure $ 
      H.div {} [if shouldBeVisible then H.text "I should be visible" else H.text "Im not visible"]
  
-}
useFeatureFlag :: Array String -> R.Hooks Boolean
useFeatureFlag keys =
  R.unsafeHooksEffect $ runEffectFn1 _useFeatureFlag keys
